#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import sys
import json
import argparse
import re
import httplib
import urllib
import bs4

parser = argparse.ArgumentParser(
		description='Parse the url to real video url using flvcd.com')
parser.add_argument('-q', '--quality',
		default=0, type=int, dest='quality',
		help="""Quality of source to download,
		values in 0(256P),1(360P),2(480P),3(720P),4(REAL).
		REAL by default.
		Note:
		If the specific resolution is not avaliable the lower nearest will be downloaded""")
parser.add_argument('url', help='The URL of the video')

args = parser.parse_args()

resolution = [
		('normal'	, 'Normal'),
		('high'	  , '360P'),
		('super'	 , '480P'),
		('super2'	, '720P'),
		('real'	  , 'REAL(DEFAULT)')
		]

def getFileExt(u):
	if u.find('f4v')!=-1:
		return 'f4v'
	if u.find('mp4')!=-1:
		return 'mp4'
	if u.find('flv')!=-1:
		return 'flv'
	if u.find('hlv')!=-1:
		return 'hlv'
	try:
		idx = u.rindex('.')
		if idx + 1 < len(u) - 1:
			return u[idx + 1:]
	except:
		pass
	return "video"

def parse(url, ua, fmt):
	http = httplib.HTTP("www.flvcd.com")
	http.putrequest("GET", "/parse.php?format=%s&kw=%s" % (fmt,
		urllib.quote(url)))
	http.putheader("User-Agent", ua)
	http.putheader("Host", "www.flvcd.com")
	http.putheader("Accept", "*/*")
	http.endheaders()
	try:
		errcode, errmsg, headers = http.getreply()
	except:
		return -1
	if errcode != 200:
		return -1
	res = http.getfile()
	html = ''
	data = res.read(512)
	while data != '':
		html += data
		data = res.read(512)
	html = html.decode('gbk')
	return html

if __name__ == '__main__':
	if not args.url:
		obj =  {'success': False, 'error_code': 5302, 'error_msg': 'no url parameter!'}
		print json.dumps(obj)
		sys.exit(0)
	user_agent = os.getenv('HTTP_USER_AGENT')
	if not user_agent:
		user_agent = r"Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.63 Safari/537.36"
	html = parse(args.url, user_agent, resolution[args.quality][0])
	if html == -1:
		obj =  {'success': False, 'error_code': 5401, 'error_msg': 'failed to parse video url'}
		print json.dumps(obj)
		sys.exit(0)
	soup = bs4.BeautifulSoup(html)
	video_title = ''
	inputs = soup.body.findAll('input')
	for i in inputs:
		name = i.get('name')
		if name and name=='name':
			val = i.get('value')
			if val:
		 		video_title = val.encode('utf8')
				break
	url_nodes = soup.body.find_all(class_= "mn STYLE4")
	if(len(url_nodes) <=  2):
		obj =  {'success': False, 'error_code': 5401, 'error_msg': 'failed to get video url from flvcd'}
		print json.dumps(obj)
		sys.exit(0)
	url_a = url_nodes[2].find_all("a")
	urls = []
	video_ext = ''
	for u in url_a:
		href = u.get('href')
		if href and re.match('[Hh][Tt][Tt][Pp][Ss]?://', href):
			video_url = {}
			video_url['href'] = href
			video_url['ext'] = getFileExt(href)
			if not len(video_ext):
				video_ext = video_url['ext']
			urls.append(video_url)
	obj =  {'success': True, 'video_title': video_title, 'video_ext' : video_ext, 'video_url': urls, 'video_count': len(urls)}
	print json.dumps(obj)

